@@ -16,13 +16,13 @@ from verde import grid_coordinates
 import harmonica
 
 from .. import tesseroid_gravity
-from ..constants import GRAVITATIONAL_CONST
-from ..forward._tesseroid_variable_density import (
+from .._forward._tesseroid_variable_density import (
     _density_based_discretization,
     density_minmax,
     maximum_absolute_diff,
     straight_line,
 )
+from ..constants import GRAVITATIONAL_CONST
 from .utils import run_only_with_numba
 
 # Define the accuracy threshold for tesseroids (0.1%) as a
@@ -260,7 +260,7 @@ def test_density_based_discret_with_delta(
     splits = []
     for delta in deltas:
         # Override the DELTA_RATIO global variable
-        harmonica.forward._tesseroid_variable_density.DELTA_RATIO = delta
+        harmonica._forward._tesseroid_variable_density.DELTA_RATIO = delta
         # Count the splits generated by density based discretization
         splits.append(len(_density_based_discretization(tesseroid, quadratic_density)))
     splits = np.array(splits)
